/*  Glimmer - findbar.h
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _FINDBAR_H_
#define _FINDBAR_H_

#ifdef __cplusplus
extern "C" {
#endif

#include "declarations.h"

void make_find_toolbar(void);
void execute_find_cb(GtkWidget* widget, gpointer data);
void find_combo_set_history(GList *history);
gboolean find_combo_add_string(gchar *string);

extern GtkWidget *findbar;
extern GtkWidget *find_combo;
extern GtkWidget *find_entry;

#ifdef __cplusplus
}
#endif

#endif
